# APRSD Webchat

[![PyPI](https://img.shields.io/pypi/v/aprsd-webchat-extension.svg)](https://pypi.org/project/aprsd-webchat-extension/)
[![Status](https://img.shields.io/pypi/status/aprsd-webchat-extension.svg)](https://pypi.org/project/aprsd-webchat-extension/)
[![Python Version](https://img.shields.io/pypi/pyversions/aprsd-webchat-extension)](https://pypi.org/project/aprsd-webchat-extension)
[![License](https://img.shields.io/pypi/l/aprsd-webchat-extension)](https://opensource.org/licenses/Apache%20Software%20License%202.0)

[![Read the documentation at https://aprsd-webchat-extension.readthedocs.io/](https://img.shields.io/readthedocs/aprsd-webchat-extension/latest.svg?label=Read%20the%20Docs)](https://aprsd-webchat-extension.readthedocs.io/)
[![Tests](https://github.com/hemna/aprsd-webchat-extension/workflows/Tests/badge.svg)](https://github.com/hemna/aprsd-webchat-extension/actions?workflow=Tests)
[![Codecov](https://codecov.io/gh/hemna/aprsd-webchat-extension/branch/main/graph/badge.svg)](https://codecov.io/gh/hemna/aprsd-webchat-extension)

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)

![APRSD WebChat Interface](./screenshot.png)

## Features

-   This is the webchat extension for APRSD. This was removed from APRSD
    proper to help those installs that don\'t want/need the webchat
    capability and all of it\'s requirements.

## Requirements

-   aprsd \>= 3.5.0

## Installation

You can install *APRSD Webchat* via [pip](https://pip.pypa.io/) from
[PyPI](https://pypi.org/):

``` console
$ pip install aprsd-webchat-extension
```

## Usage

After the install you can run webchat with the following

``` console
$ aprsd webchat --loglevel DEBUG
```

## Contributing

Contributions are very welcome. To learn more, see the [Contributor
Guide](CONTRIBUTING.rst).

## License

Distributed under the terms of the [Apache Software License 2.0
license](https://opensource.org/licenses/Apache%20Software%20License%202.0),
*APRSD Webchat* is free and open source software.

## Issues

If you encounter any problems, please [file an
issue](https://github.com/hemna/aprsd-webchat-extension/issues) along
with a detailed description.

## Credits

This project was generated from [\@hemna](https://github.com/hemna)\'s
[APRSD Extension Python Cookiecutter]() template.
